"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var dom_1 = require("../util/dom");
var util_1 = require("../util");
var Component = /** @class */ (function () {
    function Component(attrs, props) {
        //tag name
        this.tagName = 'div';
        this.children = [];
        this.renderComp = util_1.onceInTime(this.renderComponent.bind(this));
        //observer data
        this._data = {};
        Object.assign(this, attrs);
        this.props = props;
        this.$el = this.render(props);
    }
    Object.defineProperty(Component.prototype, "data", {
        get: function () {
            return this._data;
        },
        set: function (value) {
            this._data = value;
            this.updateComponent();
        },
        enumerable: true,
        configurable: true
    });
    Component.prototype.mount = function (el) {
        if (el) {
            dom_1.appendToElement(el, this.$el);
            //render components
            this.renderComp();
        }
        else {
            return this.$el;
        }
    };
    Component.prototype.renderComponent = function () {
        var _this = this;
        Object.keys(this.components).forEach(function (name) {
            var component = new _this.components[name]({}, _this.data);
            _this.children.push(component);
            dom_1.appendToElement(_this.$el, component.$el);
        });
    };
    Component.prototype.updateComponent = function () {
        this.removeChildren();
        this.renderComp();
    };
    Component.prototype.removeChildren = function () {
        this.children.forEach(function (comp) {
            comp.destroy();
        });
        this.children = [];
    };
    Component.prototype.destroy = function () {
        this.removeChildren();
        this.$el && this.$el.parentNode && this.$el.parentNode.removeChild(this.$el);
    };
    return Component;
}());
exports.default = Component;
//# sourceMappingURL=Component.js.map