"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function createElement(_a) {
    var tagName = _a.tagName, attrs = _a.attrs, content = _a.content;
    var el = document.createElement(tagName);
    if (attrs) {
        Object.keys(attrs).forEach(function (key) {
            if (key === 'style') {
                applyStyle({ el: el, props: attrs[key] });
            }
            else {
                el.setAttribute(key, attrs[key]);
            }
        });
    }
    if (typeof content === 'string') {
        el.innerHTML = content;
    }
    else if (content != null) {
        appendToElement(el, content);
    }
    return el;
}
exports.createElement = createElement;
function appendToElement(el, content) {
    var childNodes = normalizeContent(content);
    for (var i = 0; i < childNodes.length; i++) {
        el.appendChild(childNodes[i]);
    }
}
exports.appendToElement = appendToElement;
function normalizeContent(content) {
    var els;
    if (typeof content === 'string') {
        els = htmlToElements(content);
    }
    else if (content instanceof Node) {
        els = [content];
    }
    else {
        els = Array.prototype.slice.call(content);
    }
    return els;
}
function htmlToElement(html) {
    html = html.trim();
    var container = document.createElement('div');
    container.innerHTML = html;
    return container.firstChild;
}
exports.htmlToElement = htmlToElement;
function htmlToElements(html) {
    return Array.prototype.slice.call(htmlToNodeList(html));
}
exports.htmlToElements = htmlToElements;
function htmlToNodeList(html) {
    html = html.trim();
    var container = document.createElement(html);
    container.innerHTML = html;
    return container.childNodes;
}
var PIXEL_PROP_RE = /(top|left|right|bottom|width|height)$/i;
function applyStyle(_a) {
    var el = _a.el, props = _a.props;
    for (var propName in props) {
        applyStyleProp({ el: el, name: propName, val: props[propName] });
    }
}
exports.applyStyle = applyStyle;
function applyStyleProp(_a) {
    var el = _a.el, name = _a.name, val = _a.val;
    if (val == null) {
        el.style[name] = '';
    }
    else if (typeof val === 'number' && PIXEL_PROP_RE.test(name)) {
        el.style[name] = val + 'px';
    }
    else {
        el.style[name] = val;
    }
}
exports.applyStyleProp = applyStyleProp;
//# sourceMappingURL=dom.js.map